pub struct MockLlmProvider { /* private fields */ }Expand description
A mock LLM provider for testing and development.
Implementations
Sourceimpl MockLlmProvider
impl MockLlmProvider
pub fn new() -> Self
Sourcepub fn with_response(text: &str) -> Self
pub fn with_response(text: &str) -> Self
Create a MockLlmProvider that always returns the given text.
Queues multiple copies of the response so it can handle multiple calls.
Sourcepub fn queue_response(&self, response: CompletionResponse)
pub fn queue_response(&self, response: CompletionResponse)
Queue a response to be returned by the next complete call.
Sourcepub fn text_response(text: &str) -> CompletionResponse
pub fn text_response(text: &str) -> CompletionResponse
Create a simple text response for testing.
Sourcepub fn tool_call_response(
tool_name: &str,
arguments: Value,
) -> CompletionResponse
pub fn tool_call_response( tool_name: &str, arguments: Value, ) -> CompletionResponse
Create a tool call response for testing.
Sourcepub fn multipart_response(
text: &str,
tool_name: &str,
arguments: Value,
) -> CompletionResponse
pub fn multipart_response( text: &str, tool_name: &str, arguments: Value, ) -> CompletionResponse
Create a multipart response (text + tool call) for testing.