pub struct BrowserSession { /* private fields */ }Expand description
Manages a browser session including page lifecycle and security enforcement.
Implementations
Sourceimpl BrowserSession
impl BrowserSession
Sourcepub fn new(
client: Arc<dyn CdpClient>,
security: Arc<BrowserSecurityGuard>,
max_pages: usize,
) -> Self
pub fn new( client: Arc<dyn CdpClient>, security: Arc<BrowserSecurityGuard>, max_pages: usize, ) -> Self
Create a new browser session.
Sourcepub fn security(&self) -> &Arc<BrowserSecurityGuard>
pub fn security(&self) -> &Arc<BrowserSecurityGuard>
Get the security guard.
Navigate to a URL, checking security restrictions first.
Sourcepub async fn snapshot(
&self,
mode: SnapshotMode,
) -> Result<PageSnapshot, BrowserError>
pub async fn snapshot( &self, mode: SnapshotMode, ) -> Result<PageSnapshot, BrowserError>
Take a snapshot of the current page in the specified mode.
Sourcepub fn can_open_page(&self) -> bool
pub fn can_open_page(&self) -> bool
Check if a new page can be opened.
Sourcepub fn open_page(&mut self) -> Result<(), BrowserError>
pub fn open_page(&mut self) -> Result<(), BrowserError>
Record a new page being opened.
Sourcepub fn close_page(&mut self)
pub fn close_page(&mut self)
Record a page being closed.
Sourcepub async fn close(&mut self) -> Result<(), BrowserError>
pub async fn close(&mut self) -> Result<(), BrowserError>
Close the entire browser session.
Sourcepub fn open_page_count(&self) -> usize
pub fn open_page_count(&self) -> usize
Current number of open pages.