pub struct ChannelManager { /* private fields */ }Expand description
Manages a set of registered channels.
When a PairingManager is attached, it can be used to verify that
incoming DM senders are paired before processing their messages.
Implementations
Sourceimpl ChannelManager
impl ChannelManager
pub fn new() -> Self
Sourcepub fn with_pairing(self, pairing: PairingManager) -> Self
pub fn with_pairing(self, pairing: PairingManager) -> Self
Attach a pairing manager for device-pairing enforcement.
Sourcepub fn pairing(&self) -> Option<&PairingManager>
pub fn pairing(&self) -> Option<&PairingManager>
Access the pairing manager, if present.
Sourcepub fn pairing_mut(&mut self) -> Option<&mut PairingManager>
pub fn pairing_mut(&mut self) -> Option<&mut PairingManager>
Mutable access to the pairing manager, if present.
Sourcepub fn channel_count(&self) -> usize
pub fn channel_count(&self) -> usize
Number of registered channels.
Sourcepub fn channel_names(&self) -> Vec<&str>
pub fn channel_names(&self) -> Vec<&str>
List all registered channel names.
Sourcepub fn channel_status(&self, name: &str) -> Option<ChannelStatus>
pub fn channel_status(&self, name: &str) -> Option<ChannelStatus>
Get the status of a channel by name.
Sourcepub async fn connect_all(&mut self) -> Vec<(String, Result<(), RustantError>)>
pub async fn connect_all(&mut self) -> Vec<(String, Result<(), RustantError>)>
Connect all registered channels.
Sourcepub async fn disconnect_all(
&mut self,
) -> Vec<(String, Result<(), RustantError>)>
pub async fn disconnect_all( &mut self, ) -> Vec<(String, Result<(), RustantError>)>
Disconnect all registered channels.
Sourcepub async fn broadcast(
&self,
msg: ChannelMessage,
) -> Vec<(String, Result<MessageId, RustantError>)>
pub async fn broadcast( &self, msg: ChannelMessage, ) -> Vec<(String, Result<MessageId, RustantError>)>
Broadcast a message to all connected channels.
Sourcepub async fn poll_all(
&self,
) -> Vec<(String, Result<Vec<ChannelMessage>, RustantError>)>
pub async fn poll_all( &self, ) -> Vec<(String, Result<Vec<ChannelMessage>, RustantError>)>
Poll all connected channels for new messages.
Sourcepub async fn send_to(
&self,
channel_name: &str,
msg: ChannelMessage,
) -> Result<MessageId, RustantError>
pub async fn send_to( &self, channel_name: &str, msg: ChannelMessage, ) -> Result<MessageId, RustantError>
Send a message to a specific channel by name.
Sourcepub fn connected_count(&self) -> usize
pub fn connected_count(&self) -> usize
Get number of connected channels.
Sourcepub fn get_capabilities(
&self,
channel_name: &str,
) -> Option<ChannelCapabilities>
pub fn get_capabilities( &self, channel_name: &str, ) -> Option<ChannelCapabilities>
Get the capabilities of a channel by name.
Sourcepub fn channels_supporting_threads(&self) -> Vec<&str>
pub fn channels_supporting_threads(&self) -> Vec<&str>
List names of channels that support threads.
Sourcepub fn channels_by_streaming_mode(&self) -> HashMap<&str, StreamingMode>
pub fn channels_by_streaming_mode(&self) -> HashMap<&str, StreamingMode>
Map of channel names to their streaming modes.