pub fn example_tasks(info: &ProjectInfo) -> Vec<String>Expand description
Generate example tasks tailored to the detected project type.
pub fn example_tasks(info: &ProjectInfo) -> Vec<String>Generate example tasks tailored to the detected project type.