Module workflow

Module workflow 

Workflow Engine for Rustant.

Provides a declarative YAML DSL for defining multi-step workflows with typed parameters, approval gates, conditional execution, and error handling.

Re-exports

pub use builtins::all_builtins;
pub use builtins::get_builtin;
pub use builtins::list_builtin_names;
pub use executor::ApprovalHandler;
pub use executor::AutoApproveHandler;
pub use executor::AutoDenyHandler;
pub use executor::ToolExecutor;
pub use executor::WorkflowExecutor;
pub use parser::parse_workflow;
pub use parser::validate_workflow;
pub use types::ApprovalDecision;
pub use types::ErrorAction;
pub use types::GateConfig;
pub use types::GateType;
pub use types::WorkflowDefinition;
pub use types::WorkflowInput;
pub use types::WorkflowOutput;
pub use types::WorkflowState;
pub use types::WorkflowStatus;
pub use types::WorkflowStep;

Modules

builtins
Built-in workflow definitions shipped with Rustant.
executor
Workflow executor — runs workflow steps sequentially, gating on approvals, handling errors, and persisting state for pause/resume.
parser
YAML DSL parser and validator for workflow definitions.
templates
Template expression engine for workflow parameter substitution.
types
Workflow type definitions for the Rustant workflow engine.