pub fn render_string(
template: &str,
ctx: &TemplateContext,
) -> Result<String, WorkflowError>Expand description
Render template expressions in a string value, replacing {{ ... }} patterns.
pub fn render_string(
template: &str,
ctx: &TemplateContext,
) -> Result<String, WorkflowError>Render template expressions in a string value, replacing {{ ... }} patterns.