Shared toggle state for voice commands and meeting recording.
Provides a single ToggleState that all interfaces (REPL, TUI,
Gateway, Dashboard) share to start/stop voice and meeting sessions.
Structs
- Toggle
State - Shared state container for voice command and meeting recording toggles.